@@ -409,12 +409,13 @@ return value.
 
 =head1 SEE ALSO
 
-L<Audio::MPD>
+For all related information (bug reporting, mailing-list, pointers to
+MPD, etc.), refer to C<Audio::MPD>'s pod, section C<SEE ALSO>
 
 
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin at cpan.org> >>
+Jerome Quelin, C<< <jquelin@cpan.org> >>
 
 
 =head1 COPYRIGHT & LICENSE
